@@ -244,20 +244,20 @@ func (c *authOperator) Key() (metav1.Object, error) {
 func (c *authOperator) Sync(obj metav1.Object) error {
 	operatorConfig := obj.(*operatorv1.Authentication)
 
-	// TODO bump and use IsOperatorManaged
 	if operatorConfig.Spec.ManagementState != operatorv1.Managed {
 		return nil // TODO do something better for all states
 	}
 
 	operatorConfigCopy := operatorConfig.DeepCopy()
 
-	// clear degraded status
-	setDegradedFalse(operatorConfigCopy)
-
 	syncErr := c.handleSync(operatorConfigCopy)
-	if syncErr != nil {
-		setDegradedTrue(operatorConfigCopy, "OperatorSyncLoopError", syncErr.Error())
+	// this is a catch all degraded state that we only set when we are otherwise not degraded
+	globalDegradedErr := syncErr
+	const globalDegradedPrefix = "OperatorSync"
+	if isDegradedIgnoreGlobal(operatorConfigCopy, globalDegradedPrefix) {
+		globalDegradedErr = nil // unset because we are already degraded for some other reason
 	}
+	handleDegraded(operatorConfigCopy, globalDegradedPrefix, globalDegradedErr)
 
 	if _, _, err := v1helpers.UpdateStatus(c.authOperatorConfigClient, func(status *operatorv1.OperatorStatus) error {
 		// store a copy of our starting conditions, we need to preserve last transition time
@@ -294,12 +294,6 @@ func (c *authOperator) handleSync(operatorConfig *operatorv1.Authentication) err
 	// TODO move this hash from deployment meta to operatorConfig.status.generations.[...].hash
 	resourceVersions := []string{}
 
-	brandingSecret, err := c.handleOCPBrandingSecret()
-	if err != nil {
-		return fmt.Errorf("failed getting the OCP branding secret: %v", err)
-	}
-	resourceVersions = append(resourceVersions, brandingSecret.GetResourceVersion())
-
 	// The BLOCK sections are highly order dependent
 
 	// ==================================
@@ -309,26 +303,23 @@ func (c *authOperator) handleSync(operatorConfig *operatorv1.Authentication) err
 	if err != nil {
 		return fmt.Errorf("failed getting the ingress config: %v", err)
 	}
-	resourceVersions = append(resourceVersions, ingress.GetResourceVersion())
 
-	route, routerSecret, err := c.handleRoute(ingress)
+	route, routerSecret, reason, err := c.handleRoute(ingress)
+	handleDegradedWithReason(operatorConfig, "RouteStatus", reason, err)
 	if err != nil {
 		return fmt.Errorf("failed handling the route: %v", err)
 	}
-	resourceVersions = append(resourceVersions, route.GetResourceVersion(), routerSecret.GetResourceVersion())
 
 	// make sure API server sees our metadata as soon as we've got a route with a host
-	metadata, _, err := resourceapply.ApplyConfigMap(c.configMaps, c.recorder, getMetadataConfigMap(route))
+	_, _, err = resourceapply.ApplyConfigMap(c.configMaps, c.recorder, getMetadataConfigMap(route))
 	if err != nil {
 		return fmt.Errorf("failure applying configMap for the .well-known endpoint: %v", err)
 	}
-	resourceVersions = append(resourceVersions, metadata.GetResourceVersion())
 
 	authConfig, err := c.handleAuthConfig()
 	if err != nil {
 		return fmt.Errorf("failed handling authentication config: %v", err)
 	}
-	resourceVersions = append(resourceVersions, authConfig.GetResourceVersion())
 
 	// ==================================
 	// BLOCK 2: service and service-ca data
@@ -339,13 +330,11 @@ func (c *authOperator) handleSync(operatorConfig *operatorv1.Authentication) err
 	if err != nil {
 		return fmt.Errorf("failed applying service object: %v", err)
 	}
-	resourceVersions = append(resourceVersions, service.GetResourceVersion())
 
-	serviceCA, servingCert, err := c.handleServiceCA()
+	_, _, err = c.handleServiceCA()
 	if err != nil {
 		return fmt.Errorf("failed handling service CA: %v", err)
 	}
-	resourceVersions = append(resourceVersions, serviceCA.GetResourceVersion(), servingCert.GetResourceVersion())
 
 	// ==================================
 	// BLOCK 3: build cli config
@@ -355,35 +344,29 @@ func (c *authOperator) handleSync(operatorConfig *operatorv1.Authentication) err
 	if err != nil {
 		return fmt.Errorf("failed obtaining session secret: %v", err)
 	}
-	sessionSecret, _, err := resourceapply.ApplySecret(c.secrets, c.recorder, expectedSessionSecret)
+	_, _, err = resourceapply.ApplySecret(c.secrets, c.recorder, expectedSessionSecret)
 	if err != nil {
 		return fmt.Errorf("failed applying session secret: %v", err)
 	}
-	resourceVersions = append(resourceVersions, sessionSecret.GetResourceVersion())
 
 	consoleConfig := c.handleConsoleConfig()
-	resourceVersions = append(resourceVersions, consoleConfig.GetResourceVersion())
 
 	infrastructureConfig := c.handleInfrastructureConfig()
-	resourceVersions = append(resourceVersions, infrastructureConfig.GetResourceVersion())
 
-	oauthConfig, expectedCLIconfig, syncData, err := c.handleOAuthConfig(operatorConfig, route, routerSecret, service, consoleConfig, infrastructureConfig)
+	expectedCLIconfig, syncData, err := c.handleOAuthConfig(operatorConfig, route, routerSecret, service, consoleConfig, infrastructureConfig)
 	if err != nil {
 		return fmt.Errorf("failed handling OAuth configuration: %v", err)
 	}
-	resourceVersions = append(resourceVersions, oauthConfig.GetResourceVersion())
 
-	configResourceVersions, err := c.handleConfigSync(syncData)
+	err = c.handleConfigSync(syncData)
 	if err != nil {
 		return fmt.Errorf("failed syncing configuration objects: %v", err)
 	}
-	resourceVersions = append(resourceVersions, configResourceVersions...)
 
-	cliConfig, _, err := resourceapply.ApplyConfigMap(c.configMaps, c.recorder, expectedCLIconfig)
+	_, _, err = resourceapply.ApplyConfigMap(c.configMaps, c.recorder, expectedCLIconfig)
 	if err != nil {
 		return fmt.Errorf("failed applying configMap for the CLI configuration: %v", err)
 	}
-	resourceVersions = append(resourceVersions, cliConfig.GetResourceVersion())
 
 	// ==================================
 	// BLOCK 4: deployment
@@ -393,7 +376,14 @@ func (c *authOperator) handleSync(operatorConfig *operatorv1.Authentication) err
 	if err != nil {
 		return err
 	}
-	resourceVersions = append(resourceVersions, operatorDeployment.GetResourceVersion())
+	// prefix the RV to make it clear where it came from since each resource can be from different etcd
+	resourceVersions = append(resourceVersions, "deployments:"+operatorDeployment.ResourceVersion)
+
+	configResourceVersions, err := c.handleConfigResourceVersions()
+	if err != nil {
+		return err
+	}
+	resourceVersions = append(resourceVersions, configResourceVersions...)
 
 	// deployment, have RV of all resources
 	expectedDeployment := defaultDeployment(
@@ -445,7 +435,8 @@ func (c *authOperator) handleVersion(
 	// route + well-known + OAuth client checks AND one available OAuth server pod
 	// but we do NOT want to go to the next version until all OAuth server pods are at that version
 
-	routeReady, routeMsg, err := c.checkRouteHealthy(route, routerSecret, ingress)
+	routeReady, routeMsg, reason, err := c.checkRouteHealthy(route, routerSecret, ingress)
+	handleDegradedWithReason(operatorConfig, "RouteHealth", reason, err)
 	if err != nil {
 		return fmt.Errorf("unable to check route health: %v", err)
 	}
@@ -455,6 +446,7 @@ func (c *authOperator) handleVersion(
 	}
 
 	wellknownReady, wellknownMsg, err := c.checkWellknownEndpointsReady(authConfig, route)
+	handleDegraded(operatorConfig, "WellKnownEndpoint", err)
 	if err != nil {
 		return fmt.Errorf("unable to check the .well-known endpoint: %v", err)
 	}
@@ -464,6 +456,7 @@ func (c *authOperator) handleVersion(
 	}
 
 	oauthClientsReady, oauthClientsMsg, err := c.oauthClientsReady(route)
+	handleDegraded(operatorConfig, "OAuthClients", err)
 	if err != nil {
 		return fmt.Errorf("unable to check OAuth clients' readiness: %v", err)
 	}
@@ -512,30 +505,30 @@ func (c *authOperator) checkDeploymentReady(deployment *appsv1.Deployment, opera
 	return true
 }
 
-func (c *authOperator) checkRouteHealthy(route *routev1.Route, routerSecret *corev1.Secret, ingress *configv1.Ingress) (bool, string, error) {
+func (c *authOperator) checkRouteHealthy(route *routev1.Route, routerSecret *corev1.Secret, ingress *configv1.Ingress) (ready bool, msg, reason string, err error) {
 	caData := routerSecretToCA(route, routerSecret, ingress)
 
 	rt, err := transportFor("", caData, nil, nil)
 	if err != nil {
-		return false, "", fmt.Errorf("failed to build transport for route: %v", err)
+		return false, "", "FailedTransport", fmt.Errorf("failed to build transport for route: %v", err)
 	}
 
 	req, err := http.NewRequest(http.MethodHead, "https://"+route.Spec.Host+"/healthz", nil)
 	if err != nil {
-		return false, "", fmt.Errorf("failed to build request to route: %v", err)
+		return false, "", "FailedRequest", fmt.Errorf("failed to build request to route: %v", err)
 	}
 
 	resp, err := rt.RoundTrip(req)
 	if err != nil {
-		return false, "", fmt.Errorf("failed to GET route: %v", err)
+		return false, "", "FailedGet", fmt.Errorf("failed to GET route: %v", err)
 	}
 	defer resp.Body.Close()
 
-	if resp.StatusCode != 200 {
-		return false, fmt.Sprintf("route not yet available, /healthz returns '%s'", resp.Status), nil
+	if resp.StatusCode != http.StatusOK {
+		return false, fmt.Sprintf("route not yet available, /healthz returns '%s'", resp.Status), "", nil
 	}
 
-	return true, "", nil
+	return true, "", "", nil
 }
 
 func (c *authOperator) checkWellknownEndpointsReady(authConfig *configv1.Authentication, route *routev1.Route) (bool, string, error) {
